%define major 5
%define libname %mklibname tiff %{major}
%define develname %mklibname tiff -d
%define staticdevelname %mklibname tiff -d -s

Summary:	A library of functions for manipulating TIFF format image files
Name:		libtiff
Version:	4.0.2
Release:	1
License:	BSD-like
Group:		System/Libraries
URL:		http://www.remotesensing.org/libtiff/
Source0:	ftp://ftp.remotesensing.org/pub/libtiff/tiff-%{version}.tar.gz
Patch1:		tiff-3.9.1-no_contrib.diff
BuildRequires:	autoconf automake libtool m4
BuildRequires:	jbig-devel
BuildRequires:	jpeg-devel
BuildRequires:	pkgconfig(glut)
BuildRequires:	zlib-devel

%description
The libtiff package contains a library of functions for manipulating TIFF
(Tagged Image File Format) image format files. TIFF is a widely used file
format for bitmapped images. TIFF files usually end in the .tif extension
and they are often quite large.

%package	progs
Summary:	Binaries needed to manipulate TIFF format image files
Group:		Graphics
Requires:	%{libname} = %{version}

%description	progs
This package provides binaries needed to manipulate TIFF format image files.

%package -n	%{libname}
Summary:	A library of functions for manipulating TIFF format image files
Group:		System/Libraries

%description -n	%{libname}
The libtiff package contains a library of functions for manipulating TIFF
(Tagged Image File Format) image format files. TIFF is a widely used file
format for bitmapped images. TIFF files usually end in the .tif extension
and they are often quite large.

%package -n	%{develname}
Summary:	Development tools for programs which will use the libtiff library
Group:		Development/C
Requires:	%{libname} = %{version}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	tiff-devel = %{version}-%{release}
Obsoletes:	%{mklibname tiff 3 -d}

%description -n	%{develname}
This package contains the header files and .so libraries for developing
programs which will manipulate TIFF format image files using the libtiff
library.

%prep

%setup -q -n tiff-%{version}
%patch1 -p1

# cleanup
for i in `find . -type d -name CVS` `find . -type f -name .cvs\*` `find . -type f -name .#\*`; do
    if [ -e "$i" ]; then rm -rf $i; fi >&/dev/null
done

# Use build system's libtool.m4, not the one in the package.
rm -f libtool.m4

libtoolize --force  --copy
aclocal -I . -I m4
automake --add-missing --copy
autoconf
autoheader

%build
export LDFLAGS="%{ldflags}"
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

%configure2_5x

# the "JPEG 8/12 bit dual mode" is too messy..., maybe later?
# http://trac.osgeo.org/gdal/wiki/TIFF12BitJPEG
# --with-jpeg12-include-dir=
# --with-jpeg12-lib=

%make

%check
LD_LIBRARY_PATH=$PWD:$LD_LIBRARY_PATH make check

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}/{%{_bindir},%{_datadir}}

rm -rf installed_docs

%makeinstall LIBTIFF_DOCDIR=`pwd`/installed_docs

install -m0644 libtiff/tiffiop.h %{buildroot}%{_includedir}/
install -m0644 libtiff/tif_dir.h %{buildroot}%{_includedir}/

# multiarch policy
%multiarch_includes %{buildroot}%{_includedir}/tiffconf.h

# cleanup
rm -f %{buildroot}%{_libdir}/*.*a

%files progs
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%doc installed_docs/*
%{_includedir}/*.h*
%{multiarch_includedir}/tiffconf.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*


%changelog
* Wed Jul 04 2012 Oden Eriksson <oeriksson@mandriva.com> 4.0.2-1
+ Revision: 808060
- 4.0.2

* Thu Apr 05 2012 Oden Eriksson <oeriksson@mandriva.com> 4.0.1-2
+ Revision: 789292
- sync with MDVSA-2012:054

* Mon Feb 20 2012 Oden Eriksson <oeriksson@mandriva.com> 4.0.1-1
+ Revision: 777825
- fix deps
- 4.0.1

* Thu Dec 22 2011 Oden Eriksson <oeriksson@mandriva.com> 4.0.0-1
+ Revision: 744341
- 4.0.0
- drop patches not needed anymore
- various cleanups

* Sat Dec 03 2011 Oden Eriksson <oeriksson@mandriva.com> 3.9.5-2
+ Revision: 737424
- drop the static lib, its sub package and the libtool *.la file
- various fixes

* Tue Apr 12 2011 Oden Eriksson <oeriksson@mandriva.com> 3.9.5-1
+ Revision: 652807
- 3.9.5
- drop all upstream added security patches

* Mon Apr 04 2011 Oden Eriksson <oeriksson@mandriva.com> 3.9.4-5
+ Revision: 650254
- sync with MDVSA-2011:064

* Tue Mar 08 2011 Oden Eriksson <oeriksson@mandriva.com> 3.9.4-4
+ Revision: 642847
- sync slightly with libtiff-3.9.4-3.fc16.src.rpm

* Thu Sep 30 2010 Oden Eriksson <oeriksson@mandriva.com> 3.9.4-3mdv2011.0
+ Revision: 582193
- sync with MDVSA-2010:190

* Fri Aug 06 2010 Oden Eriksson <oeriksson@mandriva.com> 3.9.4-2mdv2011.0
+ Revision: 567027
- P2: security fix for CVE-2010-2595
- P3: security fix for CVE-2010-2483
- P4: security fix for CVE-2010-2597
- P5: http://bugzilla.maptools.org/show_bug.cgi?id=2218 (tiffdump crashes on unreasonably large dircount)
- P6: security fix for CVE-2010-2233
- P7: http://bugzilla.maptools.org/show_bug.cgi?id=2210 (additional fixes for CVE-2010-2481)
- P8: security fix for CVE-2010-2482

* Mon Jul 12 2010 Oden Eriksson <oeriksson@mandriva.com> 3.9.4-1mdv2011.0
+ Revision: 551257
- 3.9.4

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 3.9.2-2mdv2010.1
+ Revision: 488784
- rebuilt against libjpeg v8

* Fri Nov 06 2009 Oden Eriksson <oeriksson@mandriva.com> 3.9.2-1mdv2010.1
+ Revision: 461145
- 3.9.2
- the format string patch (P0) was applied upstream

* Fri Oct 02 2009 Oden Eriksson <oeriksson@mandriva.com> 3.9.1-4mdv2010.0
+ Revision: 452663
- fix #54150 (SPEC file contains wrong project URL)

* Sun Aug 30 2009 Oden Eriksson <oeriksson@mandriva.com> 3.9.1-3mdv2010.0
+ Revision: 422565
- fix obsoletes (anssi)

* Sun Aug 30 2009 Oden Eriksson <oeriksson@mandriva.com> 3.9.1-2mdv2010.0
+ Revision: 422558
- the devel package obsoletes itself (anssi)

* Sun Aug 30 2009 Oden Eriksson <oeriksson@mandriva.com> 3.9.1-1mdv2010.0
+ Revision: 422431
- 3.9.1
- drop all patches implemented upstream
- rediffed the string format patch
- fix cleaner docs
- cleanup the spec file a bit

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 3.8.2-16mdv2010.0
+ Revision: 416523
- rebuilt against libjpeg v7

* Tue Jul 14 2009 Oden Eriksson <oeriksson@mandriva.com> 3.8.2-15mdv2010.0
+ Revision: 395912
- P6: security fix for CVE-2009-2285 (redhat)
- P7: security fix for CVE-2009-2347 (redhat)

* Mon May 11 2009 Oden Eriksson <oeriksson@mandriva.com> 3.8.2-14mdv2010.0
+ Revision: 374654
- fix #50788 (tiff2pdf ignores JPEG compression quality)
- fix build

* Thu Dec 18 2008 Oden Eriksson <oeriksson@mandriva.com> 3.8.2-13mdv2009.1
+ Revision: 315623
- use LDFLAGS from the %%configure macro
- use %%optflags
- fix build with -Werror=format-security (P4)

* Fri Sep 05 2008 Oden Eriksson <oeriksson@mandriva.com> 3.8.2-12mdv2009.0
+ Revision: 281203
- P3: security fix for CVE-2008-2327

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 3.8.2-11mdv2009.0
+ Revision: 223011
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Tue Mar 04 2008 Oden Eriksson <oeriksson@mandriva.com> 3.8.2-10mdv2008.1
+ Revision: 178953
- rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

